@@ -1,8 +1,5 @@
 //! `libafl_targets` contains runtime code, injected in the target itself during compilation.
 
-#[macro_use]
-extern crate serde_big_array;
-
 include!(concat!(env!("OUT_DIR"), "/constants.rs"));
 
 #[cfg(any(feature = "sancov_pcguard_edges", feature = "sancov_pcguard_hitcounts"))]
